package com.srs.flowable.mapper;

import com.baomidou.mybatisplus.core.mapper.BaseMapper;
import com.srs.flowable.domain.OutsideAccommodationApproval;
import org.apache.ibatis.annotations.Param;

import java.util.List;

/**
 * 外宿申请审批记录Mapper接口
 *
 * @author srs
 * @date 2025-12-05
 */
public interface OutsideAccommodationApprovalMapper extends BaseMapper<OutsideAccommodationApproval> {
    /**
     * 查询外宿申请审批记录
     *
     * @param id 外宿申请审批记录主键
     * @return 外宿申请审批记录
     */
    public OutsideAccommodationApproval selectDmsOutsideAccommodationApprovalById(Long id);

    /**
     * 根据学生姓名学号和审批人id查询保留学籍审批记录
     *
     * @param
     * @return 结果
     */
    OutsideAccommodationApproval selectOutsideAccommodationApprovalByStuName(@Param("studentName") String studentName, @Param("studentNo") String studentNo, @Param("approverId") Long approverId);

    /**
     * 查询外宿申请审批记录列表
     *
     * @param dmsOutsideAccommodationApproval 外宿申请审批记录
     * @return 外宿申请审批记录集合
     */
    List<OutsideAccommodationApproval> selectDmsOutsideAccommodationApprovalList(OutsideAccommodationApproval dmsOutsideAccommodationApproval);

    /**
     * 新增外宿申请审批记录
     *
     * @param dmsOutsideAccommodationApproval 外宿申请审批记录
     * @return 结果
     */
    int insertDmsOutsideAccommodationApproval(OutsideAccommodationApproval dmsOutsideAccommodationApproval);

    /**
     * 修改外宿申请审批记录
     *
     * @param dmsOutsideAccommodationApproval 外宿申请审批记录
     * @return 结果
     */
    int updateDmsOutsideAccommodationApproval(OutsideAccommodationApproval dmsOutsideAccommodationApproval);

    /**
     * 删除外宿申请审批记录
     *
     * @param id 外宿申请审批记录主键
     * @return 结果
     */
    int deleteDmsOutsideAccommodationApprovalById(Long id);

    /**
     * 批量删除外宿申请审批记录
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    int deleteDmsOutsideAccommodationApprovalByIds(Long[] ids);
}
